@@ -40,10 +40,10 @@
 
 #	define PRODUCT		"tin"
 #	ifndef TIN_AUTOCONF_H
-#		define VERSION		"2.2.0"
+#		define VERSION		"2.2.1"
 #	endif /* !TIN_AUTOCONF_H */
-#	define RELEASEDATE	"20131224"
-#	define RELEASENAME	"Lochindaal"
+#	define RELEASEDATE	"20140504"
+#	define RELEASENAME	"Tober an Righ"
 /* config-file versions - must by dotted triples */
 #	define TINRC_VERSION	"1.3.12"
 #	define ATTRIBUTES_VERSION	"1.0.8"
