@@ -3,7 +3,7 @@
  *  Module    : active.c
  *  Author    : I. Lea
  *  Created   : 1992-02-16
- *  Updated   : 2013-12-06
+ *  Updated   : 2014-01-09
  *  Notes     :
  *
  * Copyright (c) 1992-2014 Iain Lea <iain@bricbrac.de>
@@ -316,7 +316,7 @@ read_newsrc_active_file(
 	int window = 0;
 	t_artnum count = T_ARTNUM_CONST(-1), min = T_ARTNUM_CONST(1), max = T_ARTNUM_CONST(0);
 	t_artnum processed = T_ARTNUM_CONST(0);
-	static char ngname[NNTP_STRLEN];
+	static char ngname[NNTP_STRLEN]; /* RFC 3977 3.1 limits group names to 497 octets */
 	struct t_group *grpptr;
 #ifdef NNTP_ABLE
 	t_bool need_auth = FALSE;
@@ -408,7 +408,7 @@ read_newsrc_active_file(
 						{
 							char fmt[25];
 
-							snprintf(fmt, sizeof(fmt), "%%"T_ARTNUM_SFMT" %%"T_ARTNUM_SFMT" %%"T_ARTNUM_SFMT" %%%ds", NNTP_STRLEN);
+							snprintf(fmt, sizeof(fmt), "%%"T_ARTNUM_SFMT" %%"T_ARTNUM_SFMT" %%"T_ARTNUM_SFMT" %%%ds", NNTP_STRLEN - 1);
 							if (sscanf(line, fmt, &count, &min, &max, ngname) != 4) {
 								error_message(2, _(txt_error_invalid_response_to_group), line);
 #	ifdef DEBUG
@@ -776,7 +776,7 @@ read_news_active_file(
 			struct t_group *grpptr;
 			t_bool need_auth = FALSE;
 
-			*buff='\0';
+			*buff = '\0';
 			/* we can't use for_each_group(i) yet, so we have to prase the newsrc */
 			if ((fp = fopen(newsrc, "r")) != NULL) {
 				while (tin_fgets(fp, FALSE) != NULL)
@@ -803,7 +803,7 @@ read_news_active_file(
 							snprintf(buff, sizeof(buff), "LIST ACTIVE %s", ptr);
 						put_server(buff);
 						r++;
-						*buff='\0';
+						*buff = '\0';
 					}
 					if (*buff) {
 						put_server(buff);
