@@ -3,7 +3,7 @@
  *  Module    : config.c
  *  Author    : I. Lea
  *  Created   : 1991-04-01
- *  Updated   : 2013-11-05
+ *  Updated   : 2014-04-26
  *  Notes     : Configuration file routines
  *
  * Copyright (c) 1991-2014 Iain Lea <iain@bricbrac.de>
@@ -1707,20 +1707,9 @@ ulBuildArgv(
 		;
 
 	buf = my_strdup(tmp);
-	if (!buf) {
-		*new_argc = 0;
-		return NULL;
-	}
+	tmp = buf;
 
 	new_argv = my_calloc(1, sizeof(char *));
-	if (!new_argv) {
-		free(buf);
-		*new_argc = 0;
-		return NULL;
-	}
-
-	tmp = buf;
-	new_argv[0] = NULL;
 
 	while (*tmp) {
 		if (!isspace((int) *tmp)) { /* found the beginning of a word */
