@@ -3,10 +3,10 @@
  *  Module    : debug.c
  *  Author    : I. Lea
  *  Created   : 1991-04-01
- *  Updated   : 2012-05-30
+ *  Updated   : 2013-11-09
  *  Notes     : debug routines
  *
- * Copyright (c) 1991-2012 Iain Lea <iain@bricbrac.de>
+ * Copyright (c) 1991-2014 Iain Lea <iain@bricbrac.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -246,18 +246,23 @@ debug_print_filter(
 	int num,
 	struct t_filter *the_filter)
 {
-	fprintf(fp, "[%3d]  group=[%s] inscope=[%s] score=[%d] case=[%s] lines=[%d %d]\n",
+	static const char sign[] = { ' ', '=', '<', '>', '\0' };
+
+	fprintf(fp, "[%3d]  group=[%s]\n       inscope=[%s] score=[%d] case=[%s]\n",
 		num, BlankIfNull(the_filter->scope),
 		(the_filter->inscope ? "TRUE" : "FILTER"),
 		the_filter->score,
-		the_filter->icase ? "C" : "I",
-		the_filter->lines_cmp, the_filter->lines_num);
+		the_filter->icase ? "C" : "I");
 
-	fprintf(fp, "       subj=[%s] from=[%s] msgid=[%s]\n",
+	fprintf(fp, "       subj=[%s]\n       from=[%s]\n       msgid=[%s]\n",
 		BlankIfNull(the_filter->subj),
 		BlankIfNull(the_filter->from),
 		BlankIfNull(the_filter->msgid));
 
+	fprintf(fp, "       lines=[%c%d] gnksa=[%c%d]\n",
+		sign[(int) the_filter->lines_cmp], the_filter->lines_num,
+		sign[(int) the_filter->gnksa_cmp], the_filter->gnksa_num);
+
 	if (the_filter->time)
 		fprintf(fp, "       time=[%ld][%s]\n", (long) the_filter->time, BlankIfNull(str_trim(ctime(&the_filter->time))));
 }
@@ -383,7 +388,7 @@ debug_print_newsrc(
 
 	fprintf(fp, "Newsrc: min=[%"T_ARTNUM_PFMT"] max=[%"T_ARTNUM_PFMT"] bitlen=[%"T_ARTNUM_PFMT"] num_unread=[%"T_ARTNUM_PFMT"] present=[%d]\n",
 		lnewsrc->xmin, lnewsrc->xmax, lnewsrc->xbitlen,
-		lnewsrc->num_unread, lnewsrc->present);
+		lnewsrc->num_unread, (lnewsrc->present ? 1 : 0));
 
 	fprintf(fp, "bitmap=[");
 	if (lnewsrc->xbitlen && lnewsrc->xbitmap) {
@@ -411,11 +416,12 @@ logtime(
 
 	if (tin_gettime(&log_time) == 0)
 	{
-		my_strftime(out, 39, " [%H:%M:%S.", gmtime(&(log_time.tv_sec)));
-		sprintf(out + 11, "%09ld", log_time.tv_nsec); /* strlen(" [hh:mm:ss.") */
-		out[17] = '\0'; /* strlen(" [hh:mm:ss.uuuuuu") */
-		strcat(out, "] ");
-		return out;
+		if (my_strftime(out, 39, " [%H:%M:%S.", gmtime(&(log_time.tv_sec)))) {
+			sprintf(out + 11, "%09ld", log_time.tv_nsec); /* strlen(" [hh:mm:ss.") */
+			out[17] = '\0'; /* strlen(" [hh:mm:ss.uuuuuu") */
+			strcat(out, "] ");
+			return out;
+		}
 	}
 #		endif /* HAVE_CLOCK_GETTIME || HAVE_GETTIMEOFDAY */
 	return " ";
