@@ -3,10 +3,10 @@
  *  Module    : xref.c
  *  Author    : I. Lea & H. Brugge
  *  Created   : 1993-07-01
- *  Updated   : 2009-04-09
+ *  Updated   : 2013-12-06
  *  Notes     :
  *
- * Copyright (c) 1993-2011 Iain Lea <iain@bricbrac.de>
+ * Copyright (c) 1993-2014 Iain Lea <iain@bricbrac.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -61,13 +61,14 @@ open_overview_fmt_fp(
 	if (read_news_via_nntp && !read_saved_news) {
 		if (!*nntp_caps.over_cmd)
 			return (FILE *) 0;
+
 		if ((nntp_caps.type == CAPABILITIES && nntp_caps.list_overview_fmt) || nntp_caps.type != CAPABILITIES)
 			return (nntp_command("LIST OVERVIEW.FMT", OK_GROUPS, NULL, 0));
-		else
-			return (FILE *) 0;
-	} else
+
+		return (FILE *) 0;
+	}
 #endif /* NNTP_ABLE */
-		return (fopen(overviewfmt_file, "r"));
+	return (fopen(overviewfmt_file, "r"));
 }
 
 
@@ -96,7 +97,7 @@ overview_xref_support(
 
 #if defined(DEBUG) && defined(NNTP_ABLE)
 			if (debug & DEBUG_NNTP)
-				debug_print_file("NNTP", "<<< %s", ptr);
+				debug_print_file("NNTP", "<<<%s%s", logtime(), ptr);
 #endif /* DEBUG && NNTP_ABLE */
 
 			fields++;
@@ -152,6 +153,13 @@ overview_xref_support(
 							debug_print_file("NNTP", "OVERVIEW.FTM: %s at position %d expected > %d", ptr, fields, 7);
 #endif /* DEBUG */
 					}
+#ifdef DEBUG
+					else {
+						if (debug & DEBUG_NNTP)
+							debug_print_file("NNTP", "OVERVIEW.FTM: %s at position %d", ptr, fields);
+					}
+#endif /* DEBUG */
+
 					continue;
 				}
 
@@ -324,7 +332,7 @@ art_mark_xref_read(
 	char *xref_ptr;
 	char *groupname;
 	char *ptr, c;
-	long artnum;
+	t_artnum artnum;
 	struct t_group *group;
 #ifdef DEBUG
 	char *debug_mesg;
@@ -356,7 +364,7 @@ art_mark_xref_read(
 			break;
 
 		ptr = xref_ptr++;
-		artnum = atol(xref_ptr);
+		artnum = atoartnum(xref_ptr);
 		while (isdigit((int) *xref_ptr))
 			xref_ptr++;
 
@@ -369,7 +377,7 @@ art_mark_xref_read(
 
 #ifdef DEBUG
 		if (debug & DEBUG_NEWSRC) {
-			debug_mesg = fmt_string("LOOKUP Xref: [%s:%ld] active=[%s] num_unread=[%ld]",
+			debug_mesg = fmt_string("LOOKUP Xref: [%s:%"T_ARTNUM_PFMT"] active=[%s] num_unread=[%"T_ARTNUM_PFMT"]",
 				groupname, artnum,
 				(group ? group->name : ""),
 				(group ? group->newsrc.num_unread : 0));
@@ -388,7 +396,7 @@ art_mark_xref_read(
 						group->newsrc.num_unread--;
 #ifdef DEBUG
 					if (debug & DEBUG_NEWSRC) {
-						debug_mesg = fmt_string("FOUND!Xref: [%s:%ld] marked READ num_unread=[%ld]",
+						debug_mesg = fmt_string("FOUND!Xref: [%s:%"T_ARTNUM_PFMT"] marked READ num_unread=[%"T_ARTNUM_PFMT"]",
 							groupname, artnum, group->newsrc.num_unread);
 							debug_print_comment(debug_mesg);
 							debug_print_bitmap(group, NULL);
@@ -410,10 +418,10 @@ art_mark_xref_read(
 void
 NSETRNG1(
 	t_bitmap *bitmap,
-	long low,
-	long high)
+	t_artnum low,
+	t_artnum high)
 {
-	long i;
+	t_artnum i;
 
 	if (bitmap == NULL) {
 #ifdef DEBUG
@@ -444,10 +452,10 @@ NSETRNG1(
 void
 NSETRNG0(
 	t_bitmap *bitmap,
-	long low,
-	long high)
+	t_artnum low,
+	t_artnum high)
 {
-	long i;
+	t_artnum i;
 
 	if (bitmap == NULL) {
 		error_message(2, "NSETRNG0() failed. Bitmap == NULL");
